==> apache-skywalking-apm-9.3.0-src.tgz: apache-skywalking-apm-9.3.0/oap-server/server-core/src/test/java/org/apache/skywalking/oap/server/core/analysis/metrics/expression/LikeMatchTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.skywalking.oap.server.core.analysis.metrics.expression;

import org.junit.Test;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class LikeMatchTest {
    @Test
    public void testLike() {
        assertTrue(new LikeMatch().match("MaxBlack", "%Black"));
        assertTrue(new LikeMatch().match("MaxBlack", "Max%"));
        assertTrue(new LikeMatch().match("MaxBlack", "%axBl%"));

        assertFalse(new LikeMatch().match("CarolineChanning", "Max%"));
        assertFalse(new LikeMatch().match("CarolineChanning", "%Max"));

        assertTrue(new LikeMatch().match("MaxBlack", "\"%Black\""));
        assertFalse(new LikeMatch().match("CarolineChanning", "\"Max%\""));
    }
}

==> apache-skywalking-apm-10.2.0-src.tgz: apache-skywalking-apm-10.2.0/oap-server/server-core/src/test/java/org/apache/skywalking/oap/server/core/analysis/metrics/expression/LikeMatchTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.skywalking.oap.server.core.analysis.metrics.expression;

import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

public class LikeMatchTest {
    @Test
    public void testLike() {
        assertTrue(new LikeMatch().match("MaxBlack", "%Black"));
        assertTrue(new LikeMatch().match("MaxBlack", "Max%"));
        assertTrue(new LikeMatch().match("MaxBlack", "%axBl%"));

        assertFalse(new LikeMatch().match("CarolineChanning", "Max%"));
        assertFalse(new LikeMatch().match("CarolineChanning", "%Max"));

        assertTrue(new LikeMatch().match("MaxBlack", "\"%Black\""));
        assertFalse(new LikeMatch().match("CarolineChanning", "\"Max%\""));
    }
}
